"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.gunzip = exports.GUnZip = void 0;
const async_1 = __importDefault(require("async"));
const fs_1 = __importDefault(require("fs"));
const zlib_1 = __importDefault(require("zlib"));
const constants_1 = require("../constants");
const path_1 = __importDefault(require("path"));
class GUnZip {
    getGruntConfig() {
        return {
            gunzip: {
                gunzip_s3_downloads: {
                    files: [
                        {
                            src: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'nodes.jsonl.gz'),
                            dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'nodes.jsonl'),
                        },
                        {
                            src: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads/', process.env.EPCC_ENV, 'products.jsonl.gz'),
                            dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'products.jsonl'),
                        },
                        {
                            src: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prices.jsonl.gz'),
                            dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prices.jsonl'),
                        },
                        {
                            src: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, '/inventory.jsonl.gz'),
                            dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'inventory.jsonl'),
                        },
                        {
                            src: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads/', process.env.EPCC_ENV, 'prod-assoc.jsonl.gz'),
                            dest: path_1.default.join(constants_1.BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prod-assoc.jsonl'),
                        },
                    ],
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('gunzip', 'Gunzip files.', function () {
            (0, exports.gunzip)(grunt, this);
        });
    }
}
exports.GUnZip = GUnZip;
const gunzip = function (grunt, grunt_this) {
    // required to make fs work, by default is running in sync mode
    const done = grunt_this.async();
    async_1.default.eachSeries(grunt_this.files, function (filePair, callback) {
        var _a;
        (_a = filePair.src) === null || _a === void 0 ? void 0 : _a.forEach(function (src) {
            grunt.log.write('Decompressing ' + src + ' ...');
            if (!filePair.dest) {
                throw Error('File destination missing');
            }
            const inp = fs_1.default.createReadStream(src, { highWaterMark: 1024 });
            const out = fs_1.default.createWriteStream(filePair.dest);
            inp.on('error', callback).on('end', callback);
            inp.pipe(zlib_1.default.createGunzip()).pipe(out);
            grunt.log.ok('');
        });
    }, done);
};
exports.gunzip = gunzip;
