import async from 'async';
import fs from 'fs';
import zlib from 'zlib';
import { BUILD_DIR } from '../constants';
import path from 'path';
export class GUnZip {
    getGruntConfig() {
        return {
            gunzip: {
                gunzip_s3_downloads: {
                    files: [
                        {
                            src: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'nodes.jsonl.gz'),
                            dest: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'nodes.jsonl'),
                        },
                        {
                            src: path.join(BUILD_DIR, 'download/ih-uploads/', process.env.EPCC_ENV, 'products.jsonl.gz'),
                            dest: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'products.jsonl'),
                        },
                        {
                            src: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prices.jsonl.gz'),
                            dest: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prices.jsonl'),
                        },
                        {
                            src: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, '/inventory.jsonl.gz'),
                            dest: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'inventory.jsonl'),
                        },
                        {
                            src: path.join(BUILD_DIR, 'download/ih-uploads/', process.env.EPCC_ENV, 'prod-assoc.jsonl.gz'),
                            dest: path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, 'prod-assoc.jsonl'),
                        },
                    ],
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('gunzip', 'Gunzip files.', function () {
            gunzip(grunt, this);
        });
    }
}
export const gunzip = function (grunt, grunt_this) {
    // required to make fs work, by default is running in sync mode
    const done = grunt_this.async();
    async.eachSeries(grunt_this.files, function (filePair, callback) {
        var _a;
        (_a = filePair.src) === null || _a === void 0 ? void 0 : _a.forEach(function (src) {
            grunt.log.write('Decompressing ' + src + ' ...');
            if (!filePair.dest) {
                throw Error('File destination missing');
            }
            const inp = fs.createReadStream(src, { highWaterMark: 1024 });
            const out = fs.createWriteStream(filePair.dest);
            inp.on('error', callback).on('end', callback);
            inp.pipe(zlib.createGunzip()).pipe(out);
            grunt.log.ok('');
        });
    }, done);
};
