import fs from 'fs';
import path from 'path';
import { BUILD_DIR } from '../constants';
export class JsonL2Json {
    getGruntConfig() {
        return {
            jsonl2json: {
                explode_s3_downloads: {
                    src: [path.join(BUILD_DIR, 'download/ih-uploads', process.env.EPCC_ENV, '*.jsonl')],
                    dest: path.join(BUILD_DIR, 'download/ih-uploads'),
                    ext: '.json',
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('jsonl2json', function () {
            jsonl2json(grunt, this);
        });
    }
}
export function jsonl2json(grunt, grunt_this) {
    const convertFile = (srcFile, targetFolder, targetExtension) => {
        const srcFileName = path.parse(srcFile).base.replace(/.jsonl$/, '');
        const array = fs.readFileSync(srcFile).toString().split('\n');
        grunt.log.writeln(`Processing ${array.length} lines`);
        for (const [index, line] of array.entries()) {
            const file = targetFolder + '/' + srcFileName + (index + 1) + targetExtension;
            grunt.log.writeln(`Processing line ${index + 1} to ${file}`);
            fs.writeFileSync(file, JSON.stringify(JSON.parse(line), null, 2));
        }
    };
    try {
        grunt_this.files.forEach(function (file) {
            grunt.log.writeln('Processing ' + file.src.length + ' files.');
            file.src.forEach((srcFile) => {
                grunt.log.writeln(`Processing ${srcFile} to ${file.dest}`);
                convertFile(srcFile, file.dest, file.ext);
            });
        });
    }
    catch (e) {
        grunt.log.writeln('Exception: ' + e);
    }
}
